globalVariables(
  names = c(
    ".parsnip_engine",
    ".",
    ".model_id",
    "fitted_wflw",
    "model_spec",
    "pred_wflw",
    "wflw",
    ".model_spec",
    "role",
    "variable"
    )
)
